﻿

----------------------------
--      Localization      --
----------------------------

local L = AceLibrary("AceLocale-2.2"):new("BunchOfBarsOptions")

L:RegisterTranslations("enUS", function() return {
	["|cffffff00Click|r to lock/unlock unit frames."] = true,
	["|cffffff00Shift-Click|r to open the configuration window."] = true,

	["There is a new revision (|cffff0000r%d|r) of |cff00ff00BunchOfBars|r available. Because |cff00ff00BunchOfBars|r is still in development it is highly recommended to install this new version."] = true
}end)

L:RegisterTranslations("koKR", function() return {
	["|cffffff00Click|r to lock/unlock unit frames."] = "|cffffff00클릭|r하면 프레임을 고정/비고정 합니다.",
	["|cffffff00Shift-Click|r to open the configuration window."] = "|cffffff00쉬프트+클릭|r하면 설정창을 엽니다.",

--	["There is a new revision (|cffff0000r%d|r) of |cff00ff00BunchOfBars|r available. Because |cff00ff00BunchOfBars|r is still in development it is highly recommended to install this new version."] = true
}end)



----------------------------------
--      Local Declaration      --
----------------------------------

local Waterfall = AceLibrary:HasInstance("Waterfall-1.0") and AceLibrary("Waterfall-1.0") or nil

local newrevision



----------------------------------
--      Module Declaration      --
----------------------------------

local options = AceLibrary("AceAddon-2.0"):new(
	"AceConsole-2.0",
	"AceEvent-2.0",
	"FuBarPlugin-2.0",
	"AceDB-2.0",

	"AceComm-2.0"
)

options.revision = tonumber(("$Revision: 40597 $"):match("%d+"))

options.defaults = { }


-- FuBar settings
options:Inject({
	hasIcon             = "Interface\\Icons\\Ability_Druid_TreeofLife",
	hasNoColor          = true,
	cannotDetachTooltip	= true,
	hideWithoutStandby  = true,
	blizzardTooltip     = true,
	hasNoText           = true,
	OnMenuRequest       = BunchOfBars.options
})



----------------------------------
--      Module Functions        --
----------------------------------

function options:OnInitialize()
	self:RegisterDB("BunchOfBarsFuBarDB")
	self:RegisterDefaults("profile", self.defaults)


	-- XXX total hack
	local args = AceLibrary("FuBarPlugin-2.0"):GetAceOptionsDataTable(self)
	for k,v in pairs(args) do
		if self.OnMenuRequest.args[k] == nil then
			self.OnMenuRequest.args[k] = v
		end
	end
	-- XXX end hack


	if Waterfall then
		Waterfall:Register(
			"BunchOfBars",
			"aceOptions", BunchOfBars.options,
			"treeType", "SECTIONS",
			"colorR", 0, "colorG", 0, "colorB", 1
		)
	end
end


function options:OnEnable()
	self:RegisterEvent("BunchOfBars_Enabled", "State")
	self:RegisterEvent("BunchOfBars_Disabled", "State")
	self:RegisterBucketEvent("PARTY_MEMBERS_CHANGED", 1, "PARTY_MEMBERS_CHANGED")

	self:State()


	for _,module in BunchOfBars:IterateModules() do
		if module.revision > self.revision then
			self.revision = module.revision
		end
	end

	BunchOfBars.revision = self.revision
	BunchOfBars.version = "r"..self.revision


	if IsInGuild() then
		newrevision = self.revision

		self:RegisterEvent("CHAT_MSG_ADDON")
		SendAddonMessage("BunchOfBars", self.revision, "GUILD")
	end
end


function options:State()
	if BunchOfBars:IsActive() then
		self:SetIcon("Interface\\Icons\\Spell_Nature_HealingTouch")
	else
		self:SetIcon("Interface\\Icons\\Ability_Druid_TreeofLife")
	end

	self:UpdateTooltip()
end


function options:OnClick(button)
	if BunchOfBars:IsActive() then
		if IsControlKeyDown() and IsAltKeyDown() then
			BunchOfBars:ToggleActive(false)
		elseif IsShiftKeyDown() and Waterfall then
			Waterfall:Open("BunchOfBars")
		else
			BunchOfBars.db.profile.visual.locked = not BunchOfBars.db.profile.visual.locked
		end
	else
		BunchOfBars:ToggleActive(true)
	end

	self:UpdateTooltip()
end


function options:OnTooltipUpdate()
	if BunchOfBars:IsActive() then
		GameTooltip:AddLine("BunchOfBars")
		GameTooltip:AddLine(" ")
		GameTooltip:AddDoubleLine(LOCKED..":", (BunchOfBars.db.profile.visual.locked and YES or NO), 1, 1, 0, 1, 1, 1) -- LOCKED, YES and NO are defined and translated somewher in blizz code
		GameTooltip:AddLine(" ")
		GameTooltip:AddLine(L["|cffffff00Click|r to lock/unlock unit frames."], 0.2, 1, 0.2)

		if Waterfall then
			GameTooltip:AddLine(L["|cffffff00Shift-Click|r to open the configuration window."], 0.2, 1, 0.2)
		end

		GameTooltip:AddLine("|cffffff00Ctrl-Alt-Click|r to disable.", 0.2, 1, 0.2)
	else
		GameTooltip:AddLine("BunchOfBars")
		GameTooltip:AddLine(" ")
		GameTooltip:AddLine("BunchOfBars is currently disabled.")
		GameTooltip:AddLine(" ")
		GameTooltip:AddLine("|cffffff00Click|r to enable.", 0.2, 1, 0.2)
	end
end


function options:PARTY_MEMBERS_CHANGED()
	if GetNumRaidMembers() > 0 or (BunchOfBars.db.profile.visual.party and GetNumPartyMembers() > 0) then
		BunchOfBars:ToggleActive(true)
	else
		BunchOfBars:ToggleActive(false)
	end
end


function options:CHAT_MSG_ADDON(prefix, message, dist, sender)
	if prefix ~= "BunchOfBars" then return end

	local num = tonumber(message)
	if num > newrevision then
		newrevision = num

		self:ScheduleEvent("BunchOfBars_Version", self.NewRevision, 20, self)
	elseif num < newrevision then
		SendAddonMessage("BunchOfBars", newrevision, "WHISPER", sender)
	end
end


function options:NewRevision()
	self:UnregisterEvent("CHAT_MSG_ADDON")
	self:Print(string.format(L["There is a new revision (|cffff0000r%d|r) of |cff00ff00BunchOfBars|r available. Because |cff00ff00BunchOfBars|r is still in development it is highly recommended to install this new version."], newrevision))
end
